@@ -60,6 +60,7 @@ import com.openexchange.mobile.api.facade.configuration.GlobalConfiguration;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
 import com.openexchange.mobile.api.facade.connectors.impl.DefaultConnectorFactoryFactory;
 import com.openexchange.mobile.api.facade.endpoints.AccountsEndpoint;
+import com.openexchange.mobile.api.facade.endpoints.AccountsEndpointV2;
 import com.openexchange.mobile.api.facade.endpoints.AuthenticationEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.ConfigEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.ContactsEndpoint;
@@ -140,6 +141,7 @@ public class Activator extends HousekeepingActivator implements Reloadable {
         AccountsService accountsService = new AccountsService(connectorFactoryFactory, foldersService);
         foldersService.setAccountsService(accountsService);
         registerService(AccountsEndpoint.class, new AccountsEndpoint(accountsService));
+        registerService(AccountsEndpointV2.class, new AccountsEndpointV2(accountsService));
 
         MailsService mailsService = new MailsService(connectorFactoryFactory);
         registerService(MailsEndpoint.class, new MailsEndpoint(mailsService));
